IF EXISTS (SELECT * FROM sys.tables WHERE name = 'TableP')
	DROP TABLE TableP
GO
IF EXISTS (SELECT * FROM sys.tables WHERE name = 'TableP1')
	DROP TABLE TableP1
GO
IF EXISTS (SELECT * FROM sys.partition_schemes WHERE name = 'TableP_Scheme')
	DROP PARTITION SCHEME TableP_Scheme
GO
IF EXISTS (SELECT * FROM sys.partition_functions WHERE name = 'TableP_Function')
	DROP PARTITION FUNCTION TableP_Function
GO
IF EXISTS (SELECT * FROM sys.database_files WHERE name = 'LowSales_Data')
	ALTER DATABASE AdventureWorksDW
		REMOVE FILE LowSales_Data	
GO
IF EXISTS (SELECT * FROM sys.filegroups WHERE name = 'LowSales')
	ALTER DATABASE AdventureWorksDW
		REMOVE FILEGROUP LowSales
GO
IF EXISTS (SELECT * FROM sys.database_files WHERE name = 'MediumSales_Data')
	ALTER DATABASE AdventureWorksDW
		REMOVE FILE MediumSales_Data
GO
IF EXISTS (SELECT * FROM sys.filegroups WHERE name = 'MediumSales')
	ALTER DATABASE AdventureWorksDW
		REMOVE FILEGROUP MediumSales
GO
IF EXISTS (SELECT * FROM sys.database_files WHERE name = 'HighSales_Data')
	ALTER DATABASE AdventureWorksDW
		REMOVE FILE HighSales_Data
GO
IF EXISTS (SELECT * FROM sys.filegroups WHERE name = 'HighSales')
	ALTER DATABASE AdventureWorksDW
		REMOVE FILEGROUP HighSales
GO
/*
Create new File Groups
*/
ALTER DATABASE AdventureWorksDW
	ADD FILEGROUP LowSales
GO
ALTER DATABASE AdventureWorksDW
	ADD FILEGROUP MediumSales
GO
ALTER DATABASE AdventureWorksDW
	ADD FILEGROUP HighSales
GO
/*
Create new Files
*/
ALTER DATABASE AdventureWorksDW
	ADD FILE (name=LowSales_Data, FileName='c:\Program Files\Microsoft SQL Server\MSSQL.1\MSSQL\Data\LowSales_Data.ndf') TO FILEGROUP LowSales
GO
ALTER DATABASE AdventureWorksDW
	ADD FILE (name=MediumSales_Data, FileName='c:\Program Files\Microsoft SQL Server\MSSQL.1\MSSQL\Data\MediumSales_Data.ndf') TO FILEGROUP MediumSales
GO
ALTER DATABASE AdventureWorksDW
	ADD FILE (name=HighSales_Data, FileName='c:\Program Files\Microsoft SQL Server\MSSQL.1\MSSQL\Data\HighSales_Data.ndf') TO FILEGROUP HighSales
GO

--Partition based on the SalesAmount column
CREATE PARTITION FUNCTION TableP_Function (money)
AS RANGE RIGHT
FOR VALUES (1000, 2000)
GO
CREATE PARTITION SCHEME TableP_Scheme
AS PARTITION TableP_Function
TO (LowSales, MediumSales, HighSales)
GO
CREATE TABLE TableP
	([ProductKey] [int] NOT NULL,
	[OrderDateKey] [int] NOT NULL,
	[DueDateKey] [int] NOT NULL,
	[ShipDateKey] [int] NOT NULL,
	[CustomerKey] [int] NOT NULL,
	[PromotionKey] [int] NOT NULL,
	[CurrencyKey] [int] NOT NULL,
	[SalesTerritoryKey] [int] NOT NULL,
	[SalesOrderNumber] [nvarchar](20) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
	[SalesOrderLineNumber] [tinyint] NOT NULL,
	[RevisionNumber] [tinyint] NULL,
	[OrderQuantity] [smallint] NULL,
	[UnitPrice] [money] NULL,
	[ExtendedAmount] [money] NULL,
	[UnitPriceDiscountPct] [float] NULL,
	[DiscountAmount] [float] NULL,
	[ProductStandardCost] [money] NULL,
	[TotalProductCost] [money] NULL,
	[SalesAmount] [money] NULL,
	[TaxAmt] [money] NULL,
	[Freight] [money] NULL,
	[CarrierTrackingNumber] [nvarchar](25) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
	[CustomerPONumber] [nvarchar](25) COLLATE SQL_Latin1_General_CP1_CI_AS NULL
) ON TableP_Scheme(SalesAmount)
GO
CREATE INDEX IX_TableP_SalesAmount ON TableP(SalesAmount)
ON TableP_Scheme(SalesAmount)
GO

CREATE TABLE TableP1
	([ProductKey] [int] NOT NULL,
	[OrderDateKey] [int] NOT NULL,
	[DueDateKey] [int] NOT NULL,
	[ShipDateKey] [int] NOT NULL,
	[CustomerKey] [int] NOT NULL,
	[PromotionKey] [int] NOT NULL,
	[CurrencyKey] [int] NOT NULL,
	[SalesTerritoryKey] [int] NOT NULL,
	[SalesOrderNumber] [nvarchar](20) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
	[SalesOrderLineNumber] [tinyint] NOT NULL,
	[RevisionNumber] [tinyint] NULL,
	[OrderQuantity] [smallint] NULL,
	[UnitPrice] [money] NULL,
	[ExtendedAmount] [money] NULL,
	[UnitPriceDiscountPct] [float] NULL,
	[DiscountAmount] [float] NULL,
	[ProductStandardCost] [money] NULL,
	[TotalProductCost] [money] NULL,
	[SalesAmount] [money] NULL,
	[TaxAmt] [money] NULL,
	[Freight] [money] NULL,
	[CarrierTrackingNumber] [nvarchar](25) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
	[CustomerPONumber] [nvarchar](25) COLLATE SQL_Latin1_General_CP1_CI_AS NULL
) ON LowSales
GO
INSERT INTO TableP
SELECT *
FROM dbo.FactInternetSales
GO
select schema_name(schema_id) [Schema], object_name(sys.partitions.object_id) TableName, Partition_number, sum(total_pages) total_pages, sum(total_pages)*8/1024 Megs
from sys.allocation_units
join sys.partitions on (sys.allocation_units.type in (1, 3) and sys.allocation_units.container_id = sys.partitions.hobt_id)
	or sys.allocation_units.type not in (1, 3) and sys.allocation_units.container_id = sys.partitions.partition_id
join sys.all_objects on sys.partitions.object_id = sys.all_objects.object_id
	and sys.all_objects.name = 'TableP'
group by schema_name(schema_id), object_name(sys.partitions.object_id), Partition_number
GO

SELECT count(*)
FROM TableP
WHERE SalesAmount < 1000

SELECT count(*)
FROM TAbleP
WHERE SalesAmount BETWEEN 1000 AND 2000

select count(*)
FROM TableP
WHERE SalesAmount > 2000
GO

/*
Quickly purging a partition
*/
SELECT COUNT(*)
FROM TableP
WHERE SalesAmount < 1000
GO
ALTER TABLE TableP SWITCH PARTITION 1 TO TableP1
GO
SELECT COUNT(*)
FROM TableP
WHERE SalesAmount < 1000
GO
SELECT count(*)
FROM TableP1